nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

SecCpuIntMask0

Struct SecCpuIntMask0 

#[repr(transparent)]
pub struct SecCpuIntMask0(pub u32);
Secure Interrupt mask for CPU1

Tuple Fields

0: u32

Implementations

Source

impl SecCpuIntMask0

pub const fn sys_irq(&self) -> bool

Watchdog Timer, Brown Out Detectors and Flash Controller interrupts

pub const fn set_sys_irq(&mut self, val: bool)

Watchdog Timer, Brown Out Detectors and Flash Controller interrupts

pub const fn sdma0_irq(&self) -> bool

System DMA 0 (non-secure) interrupt.

pub const fn set_sdma0_irq(&mut self, val: bool)

System DMA 0 (non-secure) interrupt.

pub const fn gpio_globalint0_irq(&self) -> bool

GPIO Group 0 interrupt.

pub const fn set_gpio_globalint0_irq(&mut self, val: bool)

GPIO Group 0 interrupt.

pub const fn gpio_globalint1_irq(&self) -> bool

GPIO Group 1 interrupt.

pub const fn set_gpio_globalint1_irq(&mut self, val: bool)

GPIO Group 1 interrupt.

pub const fn gpio_int0_irq0(&self) -> bool

Pin interrupt 0 or pattern match engine slice 0 interrupt.

pub const fn set_gpio_int0_irq0(&mut self, val: bool)

Pin interrupt 0 or pattern match engine slice 0 interrupt.

pub const fn gpio_int0_irq1(&self) -> bool

Pin interrupt 1 or pattern match engine slice 1 interrupt.

pub const fn set_gpio_int0_irq1(&mut self, val: bool)

Pin interrupt 1 or pattern match engine slice 1 interrupt.

pub const fn gpio_int0_irq2(&self) -> bool

Pin interrupt 2 or pattern match engine slice 2 interrupt.

pub const fn set_gpio_int0_irq2(&mut self, val: bool)

Pin interrupt 2 or pattern match engine slice 2 interrupt.

pub const fn gpio_int0_irq3(&self) -> bool

Pin interrupt 3 or pattern match engine slice 3 interrupt.

pub const fn set_gpio_int0_irq3(&mut self, val: bool)

Pin interrupt 3 or pattern match engine slice 3 interrupt.

pub const fn utick_irq(&self) -> bool

Micro Tick Timer interrupt.

pub const fn set_utick_irq(&mut self, val: bool)

Micro Tick Timer interrupt.

pub const fn mrt_irq(&self) -> bool

Multi-Rate Timer interrupt.

pub const fn set_mrt_irq(&mut self, val: bool)

Multi-Rate Timer interrupt.

pub const fn ctimer0_irq(&self) -> bool

Standard counter/timer 0 interrupt.

pub const fn set_ctimer0_irq(&mut self, val: bool)

Standard counter/timer 0 interrupt.

pub const fn ctimer1_irq(&self) -> bool

Standard counter/timer 1 interrupt.

pub const fn set_ctimer1_irq(&mut self, val: bool)

Standard counter/timer 1 interrupt.

pub const fn sct_irq(&self) -> bool

SCTimer/PWM interrupt.

pub const fn set_sct_irq(&mut self, val: bool)

SCTimer/PWM interrupt.

pub const fn ctimer3_irq(&self) -> bool

Standard counter/timer 3 interrupt.

pub const fn set_ctimer3_irq(&mut self, val: bool)

Standard counter/timer 3 interrupt.

pub const fn flexcomm0_irq(&self) -> bool

Flexcomm 0 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm0_irq(&mut self, val: bool)

Flexcomm 0 interrupt (USART, SPI, I2C, I2S).

pub const fn flexcomm1_irq(&self) -> bool

Flexcomm 1 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm1_irq(&mut self, val: bool)

Flexcomm 1 interrupt (USART, SPI, I2C, I2S).

pub const fn flexcomm2_irq(&self) -> bool

Flexcomm 2 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm2_irq(&mut self, val: bool)

Flexcomm 2 interrupt (USART, SPI, I2C, I2S).

pub const fn flexcomm3_irq(&self) -> bool

Flexcomm 3 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm3_irq(&mut self, val: bool)

Flexcomm 3 interrupt (USART, SPI, I2C, I2S).

pub const fn flexcomm4_irq(&self) -> bool

Flexcomm 4 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm4_irq(&mut self, val: bool)

Flexcomm 4 interrupt (USART, SPI, I2C, I2S).

pub const fn flexcomm5_irq(&self) -> bool

Flexcomm 5 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm5_irq(&mut self, val: bool)

Flexcomm 5 interrupt (USART, SPI, I2C, I2S).

pub const fn flexcomm6_irq(&self) -> bool

Flexcomm 6 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm6_irq(&mut self, val: bool)

Flexcomm 6 interrupt (USART, SPI, I2C, I2S).

pub const fn flexcomm7_irq(&self) -> bool

Flexcomm 7 interrupt (USART, SPI, I2C, I2S).

pub const fn set_flexcomm7_irq(&mut self, val: bool)

Flexcomm 7 interrupt (USART, SPI, I2C, I2S).

pub const fn adc_irq(&self) -> bool

General Purpose ADC interrupt.

pub const fn set_adc_irq(&mut self, val: bool)

General Purpose ADC interrupt.

pub const fn reserved0(&self) -> bool

Reserved. Read value is undefined, only zero should be written.

pub const fn set_reserved0(&mut self, val: bool)

Reserved. Read value is undefined, only zero should be written.

pub const fn acmp_irq(&self) -> bool

Analog Comparator interrupt.

pub const fn set_acmp_irq(&mut self, val: bool)

Analog Comparator interrupt.

pub const fn reserved1(&self) -> bool

Reserved. Read value is undefined, only zero should be written.

pub const fn set_reserved1(&mut self, val: bool)

Reserved. Read value is undefined, only zero should be written.

pub const fn reserved2(&self) -> bool

Reserved. Read value is undefined, only zero should be written.

pub const fn set_reserved2(&mut self, val: bool)

Reserved. Read value is undefined, only zero should be written.

pub const fn usb0_needclk(&self) -> bool

USB Full Speed Controller Clock request interrupt.

pub const fn set_usb0_needclk(&mut self, val: bool)

USB Full Speed Controller Clock request interrupt.

pub const fn usb0_irq(&self) -> bool

USB Full Speed Controller interrupt.

pub const fn set_usb0_irq(&mut self, val: bool)

USB Full Speed Controller interrupt.

pub const fn rtc_irq(&self) -> bool

RTC_LITE0_ALARM_IRQ, RTC_LITE0_WAKEUP_IRQ

pub const fn set_rtc_irq(&mut self, val: bool)

RTC_LITE0_ALARM_IRQ, RTC_LITE0_WAKEUP_IRQ

pub const fn reserved3(&self) -> bool

Reserved. Read value is undefined, only zero should be written.

pub const fn set_reserved3(&mut self, val: bool)

Reserved. Read value is undefined, only zero should be written.

pub const fn mailbox_irq(&self) -> bool

Mailbox interrupt.

pub const fn set_mailbox_irq(&mut self, val: bool)

Mailbox interrupt.